<?php
/**
 * Created by SublimeText.
 * User: loic
 * Date: 2019-07-17
 * Time: 10:31
 */

namespace WeLoveCustomers\Connector\Observer;

use Magento\Framework\App\ObjectManager;
use Magento\Framework\Event\ObserverInterface;
use Magento\SalesRule\Model\Order;
use WeLoveCustomers\Connector\Endpoint\PostOrderEndpoint;

class PaymentObserver implements ObserverInterface
{

    /**
     * @var OfferEndpoint
     */
    private $endpoint;


    /**
     * OrderObserver constructor.
     * @param RuleFactory $ruleFactory
     * @param Coupon $coupon
     * @param OfferEndpoint $endpoint
     * @param ObjectManager $objectManager
     */
    public function __construct(
        PostOrderEndpoint $endpoint)
    {
        $this->endpoint = $endpoint;
    }

    /**
     * Execute observer.
     * @param \Magento\Framework\Event\Observer $observer
     * @return $this
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
       $controller = $observer->getControllerAction();
       $order = null;

        try{
            $order = $observer->getEvent()->getInvoice()->getOrder();
        } catch(\Exception $e){}
        
        if ($order){
            $statusCode = $order->getStatus();
            $statusLabel = $order->getStatusLabel();

            $objectManager  =  \Magento\Framework\App\ObjectManager::getInstance();
            $apikey         = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/api_key');
            $apiglue        = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/api_glue');

            $orderid        = $order->getId();
            $orderIdType      = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/order_id_type');
            if ($orderIdType == "incrementId"){
                $orderid        = $order->getIncrementId();
            }
            
            $firstname      = $order->getCustomerFirstname();   // getBillingAddress()->getFirstname();
            $lastname       = $order->getCustomerLastname();    // getBillingAddress()->getLastname();
            $customername   = $firstname.' '.$lastname ;

            $email          = $order->getBillingAddress()->getEmail();
            $createdate = $order->getCreatedAt() ? strtotime($order->getCreatedAt()) : time();
            $currency       = $order->getOrderCurrencyCode();
            $priceHelper    = $objectManager->create('Magento\Framework\Pricing\Helper\Data');


            $subtotal = 0;
            $priceType      = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/price_type');
            if ($priceType == "GrandTotal"){
                $subtotal       = number_format($order->getGrandTotal(), 2); 
            } else {
                $subtotal       = number_format($order->getSubTotal(), 2); 
            }
            $coupencode     = $order->getCouponCode();
            $telephone      = $order->getBillingAddress()->getTelephone();

            $params         = array($apiglue,$customername,$email,$telephone,$subtotal,$coupencode,$createdate,$orderid);
            $hash           = md5(implode("", $params));
            $store          = $objectManager->get('Magento\Framework\Locale\Resolver'); 
            $lang           = $store->getLocale();


            $syncCustomerId      = $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('welovecustomersconnector/general/sync_customer_id');
            $customerid = '';
            if ($syncCustomerId != "no"){
                $customerid     = $order->getCustomerId();
            }



            $storeId = $websiteId = $localeCode = '';

            $storeManager = $objectManager->get('\Magento\Store\Model\StoreManagerInterface');
            try{
                $storeId = $storeManager->getStore()->getStoreId();
            } catch(\Exception $e){}

            try{
                $websiteId = $storeManager->getStore()->getWebsiteId();
            } catch(\Exception $e){}
            
            try{
                $localeCode =  $objectManager->get('Magento\Framework\App\Config\ScopeConfigInterface')->getValue('general/locale/code', \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $storeId);
            } catch(\Exception $e){}


            $orderParams = array();
            $orderParams['customer-key']        = $apikey;
            $orderParams['data-name']           = $customername;
            $orderParams['data-firstname']      = $firstname;
            $orderParams['data-lastname']       = $lastname;
            $orderParams['data-email']          = $email; 
            $orderParams['data-mobile']         = $telephone;
            $orderParams['data-amount']         = $subtotal;
            $orderParams['data-coupons']        = $coupencode;
            $orderParams['data-timestamp']      = $createdate;
            $orderParams['data-purchase-id']    = $orderid; 
            $orderParams['data-hash']           = $hash;
            $orderParams['data-lang']           = $lang;
            $orderParams['data-currency']       = $currency;
            $orderParams['data-external-id']    = $customerid;

            $orderParams['data-store-id']       = $storeId;
            $orderParams['data-website-id']     = $websiteId;
            $orderParams['data-locale-code']     = $localeCode;

            $postOrderResponse = $this->endpoint->PostOrder($orderParams);
        }
    }
}
